/** \file
   \ingroup    SASUNIT_UTIL

   \brief      initialize a test scenario, see initSASUnit.sas.
               _scenario.sas is used to initialize the SAS session 
               spawned by runSASUnit.sas

   \version    \$Revision: 315 $
   \author     \$Author: klandwich $
   \date       \$Date: 2014-02-28 10:25:18 +0100 (Fr, 28 Feb 2014) $
   \sa         For further information please refer to <A href="https://sourceforge.net/p/sasunit/wiki/User's%20Guide/" target="_blank">SASUnit User's Guide</A>
   \sa         \$HeadURL: https://svn.code.sf.net/p/sasunit/code/trunk/saspgm/sasunit/_scenario.sas $
   \copyright  Copyright 2010, 2012 HMS Analytical Software GmbH.
               This file is part of SASUnit, the Unit testing framework for SAS(R) programs.
               For terms of usage under the GPL license see included file readme.txt
               or https://sourceforge.net/p/sasunit/wiki/readme.v1.2/.

   \param   io_target       path to test database
*/ /** \cond */ 

%MACRO _scenario(io_target  = 
                );

%LOCAL l_macname; 

%LET l_macname=&sysmacroname;

OPTIONS MAUTOSOURCE MPRINT LINESIZE=MAX;

/* initialize error handling */
%_initErrorHandler;

/* check for target directory*/
%IF %_handleError(&l_macname
                 ,InvalidTargetDir
                 ,"&io_target" EQ "" OR NOT %_existDir(&io_target)
                 ,target directory &io_target does not exist
                 ) 
   %THEN %GOTO errexit;

/* create libref for test database*/
LIBNAME target "&io_target";
%IF %_handleError(&l_macname
                 ,ErrorNoTargetDirLib
                 ,%quote(&syslibrc.) NE 0
                 ,test database cannot be opened
                 ) 
   %THEN %GOTO errexit;

/* set global macro symbols and librefs / filerefs  */
/* includes creation of autocall paths */
%_loadEnvironment()
%IF &g_error_code NE %THEN %GOTO errexit;

/* flag for test cases */
%GLOBAL g_inTestcase;
%LET g_inTestcase=0;
%_oscmds;

%GOTO exit;
%errexit:
   %PUT ========================== Error! Test scenario will be aborted! ================================;
LIBNAME target;
%exit:
%MEND _scenario;
/** \endcond */
